@@ -6,17 +6,16 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
+#include "addlocationmodel.h"
 #include "alarm.h"
 #include "alarmmodel.h"
-#include "alarmplayer.h"
 #include "kclockformat.h"
-#include "savedtimezonesmodel.h"
+#include "savedlocationsmodel.h"
 #include "settingsmodel.h"
 #include "stopwatchtimer.h"
 #include "timer.h"
 #include "timermodel.h"
 #include "timerpresetmodel.h"
-#include "timezoneselectormodel.h"
 #include "utilityinterface.h"
 #include "utilmodel.h"
 #include "version.h"
@@ -40,11 +39,11 @@
 QCommandLineParser *createParser()
 {
     QCommandLineParser *parser = new QCommandLineParser;
-    parser->addOption(QCommandLineOption(QStringLiteral("page"), i18n("Select opened page"), QStringLiteral("page"), "main"));
+    parser->addOption(QCommandLineOption(QStringLiteral("page"), i18n("Select opened page"), QStringLiteral("page"), QStringLiteral("main")));
     parser->addVersionOption();
     parser->addHelpOption();
     return parser;
-};
+}
 
 int main(int argc, char *argv[])
 {
@@ -54,18 +53,25 @@ int main(int argc, char *argv[])
     }
 
     KLocalizedString::setApplicationDomain("kclock");
-    KAboutData aboutData("kclock",
-                         "Clock",
+    KAboutData aboutData(QStringLiteral("kclock"),
+                         QStringLiteral("Clock"),
                          QStringLiteral(KCLOCK_VERSION_STRING),
-                         "A convergent clock application for Plasma",
+                         QStringLiteral("Set alarms and timers, use a stopwatch, and manage world clocks"),
                          KAboutLicense::GPL,
                          i18n("© 2020-2021 KDE Community"));
-    aboutData.addAuthor(i18n("Devin Lin"), QString(), QStringLiteral("espidev@gmail.com"));
+    aboutData.setBugAddress("https://invent.kde.org/plasma-mobile/kclock/-/issues");
+    aboutData.addAuthor(i18n("Devin Lin"), QString(), QStringLiteral("devin@kde.org"));
     aboutData.addAuthor(i18n("Han Young"), QString(), QStringLiteral("hanyoung@protonmail.com"));
     KAboutData::setApplicationData(aboutData);
 
-    // only allow one instance
-    // KDBusService service(KDBusService::Unique);
+    // ensure kclockd is up with dbus autostart, any call will do
+    QDBusInterface *testInterface = new QDBusInterface(QStringLiteral("org.kde.kclockd"),
+                                                       QStringLiteral("/Alarms"),
+                                                       QStringLiteral("org.freedesktop.DBus.Introspectable"),
+                                                       QDBusConnection::sessionBus(),
+                                                       nullptr);
+    testInterface->call(QStringLiteral("Introspect"));
+    testInterface->deleteLater();
 
     // initialize models
     auto *stopwatchTimer = new StopwatchTimer();
@@ -74,24 +80,30 @@ int main(int argc, char *argv[])
     // register QML types
     qmlRegisterType<Alarm>("kclock", 1, 0, "Alarm");
     qmlRegisterType<Timer>("kclock", 1, 0, "Timer");
-    qmlRegisterType<SavedTimeZonesModel>("kclock", 1, 0, "SavedTimeZonesModel");
-    qmlRegisterType<TimeZoneFilterModel>("kclock", 1, 0, "TimeZoneFilterModel");
+
+    qmlRegisterSingletonType<AddLocationSearchModel>("kclock", 1, 0, "AddLocationSearchModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+        return AddLocationSearchModel::instance();
+    });
+    qmlRegisterSingletonType<SavedLocationsModel>("kclock", 1, 0, "SavedLocationsModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+        return SavedLocationsModel::instance();
+    });
     qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "TimerPresetModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return TimerPresetModel::instance();
     });
+    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "TimerModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+        return TimerModel::instance();
+    });
 
     QQmlApplicationEngine *engine = new QQmlApplicationEngine();
 
     engine->rootContext()->setContextObject(new KLocalizedContext(engine));
     // models
-    engine->rootContext()->setContextProperty("alarmModel", AlarmModel::instance());
-    engine->rootContext()->setContextProperty("timerModel", TimerModel::instance());
-    engine->rootContext()->setContextProperty("utilModel", UtilModel::instance());
-    engine->rootContext()->setContextProperty("stopwatchTimer", stopwatchTimer);
-    engine->rootContext()->setContextProperty("alarmPlayer", &AlarmPlayer::instance());
-    engine->rootContext()->setContextProperty("kclockFormat", KclockFormat::instance());
-    engine->rootContext()->setContextProperty("weekModel", weekModel);
-    engine->rootContext()->setContextProperty("settingsModel", &SettingsModel::instance());
+    engine->rootContext()->setContextProperty(QStringLiteral("alarmModel"), AlarmModel::instance());
+    engine->rootContext()->setContextProperty(QStringLiteral("utilModel"), UtilModel::instance());
+    engine->rootContext()->setContextProperty(QStringLiteral("stopwatchTimer"), stopwatchTimer);
+    engine->rootContext()->setContextProperty(QStringLiteral("kclockFormat"), KclockFormat::instance());
+    engine->rootContext()->setContextProperty(QStringLiteral("weekModel"), weekModel);
+    engine->rootContext()->setContextProperty(QStringLiteral("settingsModel"), SettingsModel::instance());
     engine->rootContext()->setContextProperty(QStringLiteral("kclockAboutData"), QVariant::fromValue(aboutData));
 
     engine->load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
@@ -101,13 +113,16 @@ int main(int argc, char *argv[])
         parser->process(app);
         if (parser->isSet(QStringLiteral("page"))) {
             QVariant page;
-            QMetaObject::invokeMethod(engine->rootObjects().first(), "getPage", Q_RETURN_ARG(QVariant, page), Q_ARG(QVariant, parser->value("page")));
+            QMetaObject::invokeMethod(engine->rootObjects().first(),
+                                      "getPage",
+                                      Q_RETURN_ARG(QVariant, page),
+                                      Q_ARG(QVariant, parser->value(QStringLiteral("page"))));
             QMetaObject::invokeMethod(engine->rootObjects().first(), "switchToPage", Q_ARG(QVariant, page), Q_ARG(QVariant, 0));
         }
     }
 
-    OrgKdeKclockUtilitiesInterface *interface =
-        new OrgKdeKclockUtilitiesInterface(QStringLiteral("org.kde.kclockd"), QStringLiteral("/Utility"), QDBusConnection::sessionBus());
+    OrgKdePowerManagementInterface *interface =
+        new OrgKdePowerManagementInterface(QStringLiteral("org.kde.kclockd"), QStringLiteral("/Utility"), QDBusConnection::sessionBus());
     interface->keepAlive();
     QObject::connect(&app, &QCoreApplication::aboutToQuit, &app, [interface] {
         interface->canExit();
