@@ -1,21 +1,20 @@
 /*
  * Copyright 2020 Han Young <hanyoung@protonmail.com>
- * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * Copyright 2020-2021 Devin Lin <devin@kde.org>
  * Copyright 2021 Boris Petrov <boris.v.petrov@protonmail.com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef KCLOCK_TIMERMODEL_H
-#define KCLOCK_TIMERMODEL_H
-
-#include "timermodelinterface.h"
+#pragma once
 
 #include <KLocalizedString>
 
 #include <QAbstractListModel>
 #include <QObject>
 
+#include "timermodelinterface.h"
+
 class Timer;
 class TimerModel : public QAbstractListModel
 {
@@ -23,22 +22,19 @@ class TimerModel : public QAbstractListModel
     Q_PROPERTY(bool connectedToDaemon READ connectedToDaemon NOTIFY connectedToDaemonChanged)
 
 public:
+    static TimerModel *instance();
+
+    enum {
+        TimerRole,
+    };
+
     int rowCount(const QModelIndex &parent) const override;
     QVariant data(const QModelIndex &index, int role) const override;
+    QHash<int, QByteArray> roleNames() const override;
 
-    static TimerModel *instance()
-    {
-        static TimerModel *singleton = new TimerModel();
-        return singleton;
-    }
-
-    Q_INVOKABLE void addNew(int length, QString label, QString commandTimeout)
-    {
-        this->addTimer(length, label, commandTimeout, false);
-    };
+    Q_INVOKABLE void addNew(int length, QString label, QString commandTimeout);
     Q_INVOKABLE void remove(int index);
-    Q_INVOKABLE int count();
-    Q_INVOKABLE Timer *get(int index);
+
     bool connectedToDaemon();
     void setConnectedToDaemon(bool connectedToDaemon);
 
@@ -47,11 +43,12 @@ Q_SIGNALS:
 
 private Q_SLOTS:
     void addTimer(QString uuid); // remote add, always justCreated
-    void addTimer(int length = 300, QString label = i18n("New timer"), QString commandTimeout = "", bool running = false);
+    void addTimer(int length = 300, QString label = i18n("New timer"), QString commandTimeout = QString{}, bool running = false);
     void removeTimer(QString uuid);
 
 private:
     explicit TimerModel(QObject *parent = nullptr);
+
     void addTimer(QString uuid, bool justCreated);
 
     QList<Timer *> m_timersList;
@@ -60,4 +57,3 @@ private:
     bool m_connectedToDaemon = false;
 };
 
-#endif // KCLOCK_TIMERMODEL_H
