@@ -1,12 +1,11 @@
 /*
  * Copyright 2020 Han Young <hanyoung@protonmail.com>
- * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * Copyright 2020 Devin Lin <devin@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef KCLOCKD_ALARMPLAYER_H
-#define KCLOCKD_ALARMPLAYER_H
+#pragma once
 
 #include <QMediaPlayer>
 #include <QObject>
@@ -15,18 +14,17 @@ class AlarmPlayer : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(int volume READ volume WRITE setVolume NOTIFY volumeChanged)
+
 public:
     static AlarmPlayer &instance();
-    int volume()
-    {
-        return m_player->volume();
-    };
+
+    int volume();
     Q_INVOKABLE void setVolume(int volume);
     Q_INVOKABLE void setSource(QUrl path);
     Q_INVOKABLE void play();
     Q_INVOKABLE void stop();
 
-signals:
+Q_SIGNALS:
     void volumeChanged();
 
 protected:
@@ -37,8 +35,7 @@ private:
     quint64 startPlayingTime = 0;
 
     bool userStop = false; // indicate if user asks to stop
-private slots:
+
+private Q_SLOTS:
     void loopAudio(QMediaPlayer::State state);
 };
-
-#endif // KCLOCKD_ALARMPLAYER_H
