@@ -4,30 +4,26 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef KCLOCKD_UTILITIES_H
-#define KCLOCKD_UTILITIES_H
+#pragma once
 
 #include "alarmwaitworker.h"
 
 #include <QDBusInterface>
 #include <QObject>
-class QTimer;
+
 const QString POWERDEVIL_SERVICE_NAME = QStringLiteral("org.kde.Solid.PowerManagement");
+
+class QTimer;
+
 class Utilities : public QObject
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.kde.kclock.Utilities")
-public:
-    static Utilities &instance()
-    {
-        static Utilities singleton;
-        return singleton;
-    }
+    Q_CLASSINFO("D-Bus Interface", "org.kde.PowerManagement")
 
-    bool hasPowerDevil()
-    {
-        return m_hasPowerDevil;
-    };
+public:
+    static Utilities &instance();
+
+    bool hasPowerDevil();
 
     int scheduleWakeup(quint64 timestamp);
     void clearWakeup(int cookie);
@@ -35,9 +31,12 @@ public:
     void incfActiveCount();
     void decfActiveCount();
 
+    static void wakeupNow();
+
 Q_SIGNALS:
     void wakeup(int cookie);
     void needsReschedule();
+
 public Q_SLOTS:
     Q_SCRIPTABLE void wakeupCallback(int cookie);
     Q_SCRIPTABLE void keepAlive();
@@ -64,4 +63,3 @@ private:
     QTimer *m_timer = nullptr;
 };
 
-#endif // KCLOCKD_UTILITIES_H
